Welcome to ``osdatahub's`` documentation!
==========================================

``osdatahub`` is a python package from Ordnance Survey (OS), designed to make data from the OS Data Hub APIs readily accessible to
developers.

- OS Data Hub APIs: https://osdatahub.os.uk/
- GitHub repo: https://github.com/OrdnanceSurvey/osdatahub
- Documentation: https://osdatahub.readthedocs.io/en/latest/
- PyPI: https://pypi.org/project/osdatahub/
- Free Software: Open Government License

.. toctree::
   :maxdepth: 2
 
   readme_link
   NGD
   FeaturesAPI
   PlacesAPI
   NamesAPI
   LinkedIdentifiersAPI
   DownloadsAPI
   Extent
   Utilities
   Data Hub Explorer <https://labs.os.uk/public/data-hub-explorer/>
   Examples <https://github.com/OrdnanceSurvey/osdatahub/tree/master/Examples>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
